==> colourvalues_0.3.0.tar.gz: colourvalues/inst/include/colourvalues/palettes/rainbow.hpp <==
#ifndef R_COLOURVALUES_RAINBOW_H
#define R_COLOURVALUES_RAINBOW_H

#include <Rcpp.h>
using namespace Rcpp;

namespace colourvalues {
namespace palette {

  const Rcpp::NumericVector rainbow_red = {
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,0.992156862745098,
    0.968627450980392,0.945098039215686,0.92156862745098,0.898039215686275,
    0.874509803921569,0.850980392156863,0.827450980392157,0.803921568627451,
    0.780392156862745,0.756862745098039,0.733333333333333,0.709803921568627,
    0.686274509803922,0.662745098039216,0.63921568627451,0.615686274509804,
    0.592156862745098,0.568627450980392,0.545098039215686,0.52156862745098,
    0.501960784313725,0.47843137254902,0.454901960784314,0.431372549019608,
    0.407843137254902,0.384313725490196,0.36078431372549,0.337254901960784,
    0.313725490196078,0.290196078431373,0.266666666666667,0.243137254901961,
    0.219607843137255,0.196078431372549,0.172549019607843,0.149019607843137,
    0.125490196078431,0.101960784313725,0.0784313725490196,0.0549019607843137,
    0.0313725490196078,0.00784313725490196,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0.00784313725490196,
    0.0313725490196078,0.0549019607843137,0.0784313725490196,0.101960784313725,
    0.125490196078431,0.149019607843137,0.172549019607843,0.196078431372549,
    0.219607843137255,0.243137254901961,0.266666666666667,0.290196078431373,
    0.313725490196078,0.337254901960784,0.36078431372549,0.384313725490196,
    0.407843137254902,0.431372549019608,0.454901960784314,0.47843137254902,
    0.501960784313725,0.52156862745098,0.545098039215686,0.568627450980392,
    0.592156862745098,0.615686274509804,0.63921568627451,0.662745098039216,
    0.686274509803922,0.709803921568627,0.733333333333333,0.756862745098039,
    0.780392156862745,0.803921568627451,0.827450980392157,0.850980392156863,
    0.874509803921569,0.898039215686275,0.92156862745098,0.945098039215686,
    0.968627450980392,0.992156862745098,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1
  };

  const Rcpp::NumericVector rainbow_green = {
    0,0.0235294117647059,0.0470588235294118,0.0705882352941176,
    0.0941176470588235,0.117647058823529,0.141176470588235,0.164705882352941,
    0.188235294117647,0.211764705882353,0.235294117647059,0.258823529411765,
    0.282352941176471,0.305882352941176,0.329411764705882,0.352941176470588,
    0.376470588235294,0.4,0.423529411764706,0.447058823529412,
    0.470588235294118,0.494117647058824,0.513725490196078,0.537254901960784,
    0.56078431372549,0.584313725490196,0.607843137254902,0.631372549019608,
    0.654901960784314,0.67843137254902,0.701960784313725,0.725490196078431,
    0.749019607843137,0.772549019607843,0.796078431372549,0.819607843137255,
    0.843137254901961,0.866666666666667,0.890196078431372,0.913725490196078,
    0.937254901960784,0.96078431372549,0.984313725490196,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,0.976470588235294,0.952941176470588,0.929411764705882,
    0.905882352941176,0.882352941176471,0.858823529411765,0.835294117647059,
    0.811764705882353,0.788235294117647,0.764705882352941,0.741176470588235,
    0.717647058823529,0.694117647058824,0.670588235294118,0.647058823529412,
    0.623529411764706,0.6,0.576470588235294,0.552941176470588,
    0.529411764705882,0.505882352941176,0.486274509803922,0.462745098039216,
    0.43921568627451,0.415686274509804,0.392156862745098,0.368627450980392,
    0.345098039215686,0.32156862745098,0.298039215686275,0.274509803921569,
    0.250980392156863,0.227450980392157,0.203921568627451,0.180392156862745,
    0.156862745098039,0.133333333333333,0.109803921568627,0.0862745098039216,
    0.0627450980392157,0.0392156862745098,0.0156862745098039,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0
  };

  const Rcpp::NumericVector rainbow_blue = {
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0.0156862745098039,0.0392156862745098,
    0.0627450980392157,0.0862745098039216,0.109803921568627,0.133333333333333,
    0.156862745098039,0.180392156862745,0.203921568627451,0.227450980392157,
    0.250980392156863,0.274509803921569,0.298039215686275,0.32156862745098,
    0.345098039215686,0.368627450980392,0.392156862745098,0.415686274509804,
    0.43921568627451,0.462745098039216,0.486274509803922,0.505882352941176,
    0.529411764705882,0.552941176470588,0.576470588235294,0.6,
    0.623529411764706,0.647058823529412,0.670588235294118,0.694117647058824,
    0.717647058823529,0.741176470588235,0.764705882352941,0.788235294117647,
    0.811764705882353,0.835294117647059,0.858823529411765,0.882352941176471,
    0.905882352941176,0.929411764705882,0.952941176470588,0.976470588235294,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,0.984313725490196,0.96078431372549,
    0.937254901960784,0.913725490196078,0.890196078431372,0.866666666666667,
    0.843137254901961,0.819607843137255,0.796078431372549,0.772549019607843,
    0.749019607843137,0.725490196078431,0.701960784313725,0.67843137254902,
    0.654901960784314,0.631372549019608,0.607843137254902,0.584313725490196,
    0.56078431372549,0.537254901960784,0.513725490196078,0.494117647058824,
    0.470588235294118,0.447058823529412,0.423529411764706,0.4,
    0.376470588235294,0.352941176470588,0.329411764705882,0.305882352941176,
    0.282352941176471,0.258823529411765,0.235294117647059,0.211764705882353,
    0.188235294117647,0.164705882352941,0.141176470588235,0.117647058823529,
    0.0941176470588235,0.0705882352941176,0.0470588235294118,0.0235294117647059
  };

const Rcpp::List rainbow = Rcpp::List::create(
  _["r"] = rainbow_red,
  _["g"] = rainbow_green,
  _["b"] = rainbow_blue
);
} // namespace palette
} // namepsace colourvalues

#endif

==> colourvalues_0.3.9.tar.gz: colourvalues/inst/include/colourvalues/palettes/rainbow.hpp <==
#ifndef R_COLOURVALUES_RAINBOW_H
#define R_COLOURVALUES_RAINBOW_H

#include <Rcpp.h>
using namespace Rcpp;

namespace colourvalues {
namespace palette {

  const Rcpp::NumericVector rainbow_red = {
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,0.992156862745098,
    0.968627450980392,0.945098039215686,0.92156862745098,0.898039215686275,
    0.874509803921569,0.850980392156863,0.827450980392157,0.803921568627451,
    0.780392156862745,0.756862745098039,0.733333333333333,0.709803921568627,
    0.686274509803922,0.662745098039216,0.63921568627451,0.615686274509804,
    0.592156862745098,0.568627450980392,0.545098039215686,0.52156862745098,
    0.501960784313725,0.47843137254902,0.454901960784314,0.431372549019608,
    0.407843137254902,0.384313725490196,0.36078431372549,0.337254901960784,
    0.313725490196078,0.290196078431373,0.266666666666667,0.243137254901961,
    0.219607843137255,0.196078431372549,0.172549019607843,0.149019607843137,
    0.125490196078431,0.101960784313725,0.0784313725490196,0.0549019607843137,
    0.0313725490196078,0.00784313725490196,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0.00784313725490196,
    0.0313725490196078,0.0549019607843137,0.0784313725490196,0.101960784313725,
    0.125490196078431,0.149019607843137,0.172549019607843,0.196078431372549,
    0.219607843137255,0.243137254901961,0.266666666666667,0.290196078431373,
    0.313725490196078,0.337254901960784,0.36078431372549,0.384313725490196,
    0.407843137254902,0.431372549019608,0.454901960784314,0.47843137254902,
    0.501960784313725,0.52156862745098,0.545098039215686,0.568627450980392,
    0.592156862745098,0.615686274509804,0.63921568627451,0.662745098039216,
    0.686274509803922,0.709803921568627,0.733333333333333,0.756862745098039,
    0.780392156862745,0.803921568627451,0.827450980392157,0.850980392156863,
    0.874509803921569,0.898039215686275,0.92156862745098,0.945098039215686,
    0.968627450980392,0.992156862745098,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1
  };

  const Rcpp::NumericVector rainbow_green = {
    0,0.0235294117647059,0.0470588235294118,0.0705882352941176,
    0.0941176470588235,0.117647058823529,0.141176470588235,0.164705882352941,
    0.188235294117647,0.211764705882353,0.235294117647059,0.258823529411765,
    0.282352941176471,0.305882352941176,0.329411764705882,0.352941176470588,
    0.376470588235294,0.4,0.423529411764706,0.447058823529412,
    0.470588235294118,0.494117647058824,0.513725490196078,0.537254901960784,
    0.56078431372549,0.584313725490196,0.607843137254902,0.631372549019608,
    0.654901960784314,0.67843137254902,0.701960784313725,0.725490196078431,
    0.749019607843137,0.772549019607843,0.796078431372549,0.819607843137255,
    0.843137254901961,0.866666666666667,0.890196078431372,0.913725490196078,
    0.937254901960784,0.96078431372549,0.984313725490196,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,0.976470588235294,0.952941176470588,0.929411764705882,
    0.905882352941176,0.882352941176471,0.858823529411765,0.835294117647059,
    0.811764705882353,0.788235294117647,0.764705882352941,0.741176470588235,
    0.717647058823529,0.694117647058824,0.670588235294118,0.647058823529412,
    0.623529411764706,0.6,0.576470588235294,0.552941176470588,
    0.529411764705882,0.505882352941176,0.486274509803922,0.462745098039216,
    0.43921568627451,0.415686274509804,0.392156862745098,0.368627450980392,
    0.345098039215686,0.32156862745098,0.298039215686275,0.274509803921569,
    0.250980392156863,0.227450980392157,0.203921568627451,0.180392156862745,
    0.156862745098039,0.133333333333333,0.109803921568627,0.0862745098039216,
    0.0627450980392157,0.0392156862745098,0.0156862745098039,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0
  };

  const Rcpp::NumericVector rainbow_blue = {
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0,0,
    0,0,0.0156862745098039,0.0392156862745098,
    0.0627450980392157,0.0862745098039216,0.109803921568627,0.133333333333333,
    0.156862745098039,0.180392156862745,0.203921568627451,0.227450980392157,
    0.250980392156863,0.274509803921569,0.298039215686275,0.32156862745098,
    0.345098039215686,0.368627450980392,0.392156862745098,0.415686274509804,
    0.43921568627451,0.462745098039216,0.486274509803922,0.505882352941176,
    0.529411764705882,0.552941176470588,0.576470588235294,0.6,
    0.623529411764706,0.647058823529412,0.670588235294118,0.694117647058824,
    0.717647058823529,0.741176470588235,0.764705882352941,0.788235294117647,
    0.811764705882353,0.835294117647059,0.858823529411765,0.882352941176471,
    0.905882352941176,0.929411764705882,0.952941176470588,0.976470588235294,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,1,1,
    1,1,0.984313725490196,0.96078431372549,
    0.937254901960784,0.913725490196078,0.890196078431372,0.866666666666667,
    0.843137254901961,0.819607843137255,0.796078431372549,0.772549019607843,
    0.749019607843137,0.725490196078431,0.701960784313725,0.67843137254902,
    0.654901960784314,0.631372549019608,0.607843137254902,0.584313725490196,
    0.56078431372549,0.537254901960784,0.513725490196078,0.494117647058824,
    0.470588235294118,0.447058823529412,0.423529411764706,0.4,
    0.376470588235294,0.352941176470588,0.329411764705882,0.305882352941176,
    0.282352941176471,0.258823529411765,0.235294117647059,0.211764705882353,
    0.188235294117647,0.164705882352941,0.141176470588235,0.117647058823529,
    0.0941176470588235,0.0705882352941176,0.0470588235294118,0.0235294117647059
  };

  // const Rcpp::List rainbow = Rcpp::List::create(
  //   _["r"] = rainbow_red,
  //   _["g"] = rainbow_green,
  //   _["b"] = rainbow_blue
  // );
} // namespace palette
} // namepsace colourvalues

#endif
